@@ -17,6 +17,7 @@ This module defines ZFiles documents.
 
 import io
 from cgi import FieldStorage
+from datetime import datetime, timezone
 from hashlib import sha512
 
 from hypatia.interfaces import ICatalog
@@ -41,12 +42,14 @@ from pyams_utils.factory import factory_config
 from pyams_utils.interfaces.form import NOT_CHANGED
 from pyams_utils.registry import get_utility
 from pyams_utils.request import check_request
+from pyams_utils.timezone import tztime
 from pyams_utils.traversing import get_parent
 from pyams_utils.url import absolute_url
 from pyams_utils.vocabulary import vocabulary_config
 from pyams_workflow.interfaces import IWorkflowInfo, IWorkflowState
-from pyams_zfiles.interfaces import ACCESS_MODE, DocumentContainerError, IDocument, \
-    IDocumentContainer, IDocumentRoles, IDocumentVersion, MANAGE_APPLICATION_PERMISSION, \
+from pyams_zfiles.interfaces import ACCESS_MODE, DocumentContainerError, ICatalogPropertiesIndexesContainer, IDocument, \
+    IDocumentContainer, IDocumentPropertyExtractorContainer, IDocumentRoles, IDocumentVersion, \
+    MANAGE_APPLICATION_PERMISSION, \
     MANAGE_DOCUMENT_PERMISSION, PYAMS_ZFILES_APPLICATIONS_VOCABULARY, READ_DOCUMENT_PERMISSION, \
     ZFILES_WORKFLOW_NAME
 from pyams_zfiles.workflow import ZFILES_WORKFLOW
@@ -55,6 +58,9 @@ from pyams_zfiles.workflow import ZFILES_WORKFLOW
 __docformat__ = 'restructuredtext'
 
 
+_marker = object()
+
+
 def is_file_like(data):
     """Check for file-like object"""
     return hasattr(data, 'read') and hasattr(data, 'seek')
@@ -136,12 +142,23 @@ class DocumentVersion(ProtectedObjectMixin, Persistent, Contained):
         """Document properties getter used for indexing"""
         if not self.properties:
             return None
+        container = get_utility(IDocumentContainer)
+        catalog_indexes = ICatalogPropertiesIndexesContainer(container)
         return [
             f'{key}={val}'
             for key, value in self.properties.items()
             for val in value.split(';')
-            if val
+            if val and (key not in catalog_indexes.index_names)
         ]
+    
+    def get_index_property(self, property_name, default=None):
+        """Get specific index property value"""
+        if not self.properties:
+            return default
+        value = self.properties.get(property_name, _marker)
+        if value is _marker:
+            return default
+        return value.split(';') if value else None
 
     @property
     def tags(self):
@@ -174,6 +191,8 @@ class DocumentVersion(ProtectedObjectMixin, Persistent, Contained):
         self.update_security_policy(properties, request)
         self.update_status(properties, request)
         self.update_properties(properties, request)
+        self.extract_properties(properties, request)
+        self.update_title(properties, request)
         return IWorkflowState(self)
 
     def update_roles(self, properties, request=None):  # pylint: disable=unused-argument
@@ -262,6 +281,30 @@ class DocumentVersion(ProtectedObjectMixin, Persistent, Contained):
                     if val is None:
                         del self_props[key]
                 self.properties = self_props or None
+                
+    def extract_properties(self, properties, request=None):
+        """Use extractors to get properties fron document content"""
+        manager = get_utility(IDocumentContainer)
+        extractors = IDocumentPropertyExtractorContainer(manager, None)
+        if extractors is not None:
+            props = extractors.extract_properties(self)
+            if props:
+                self_props = self.properties or {}
+                self_props.update(props)
+                self.properties = self_props or {}
+                
+    def update_title(self, properties, request=None):
+        """Update document title from properties"""
+        properties = (self.properties or {}).copy()
+        properties['now'] = tztime(datetime.now(timezone.utc))
+        try:
+            self.title = self.title.format(**properties)
+        except KeyError:
+            pass
+        try:
+            self.data.filename = self.data.filename.format(**properties)
+        except KeyError:
+            pass
 
     def to_json(self, fields=None, request=None):
         """Get document properties in JSON format"""
