@@ -25,11 +25,13 @@ from hypatia.query import All, Any, Comparator, Eq, Ge, Le
 from pyams_catalog.query import and_, or_
 from pyams_utils.date import date_to_datetime
 from pyams_utils.interfaces.form import NO_VALUE_STRING
+from pyams_utils.registry import get_utility
 from pyams_utils.timezone import gmtime
 
 
 __docformat__ = 'restructuredtext'
 
+from pyams_zfiles.interfaces import ICatalogPropertiesIndexesContainer, IDocumentContainer
 
 NULL_STRING = 'null'
 LIST_SEPARATOR = ','
@@ -121,13 +123,13 @@ def get_date(value):
     >>> get_date('null') is None
     True
     >>> get_date(datetime(2021, 12, 3))
-    datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>)
+    datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>)
     >>> get_date(datetime(2021, 12, 3).isoformat())
-    datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>)
+    datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>)
     >>> get_date(datetime(2021, 12, 3, 12, 0, 0))
-    datetime.datetime(2021, 12, 3, 12, 0, tzinfo=<StaticTzInfo 'GMT'>)
+    datetime.datetime(2021, 12, 3, 12, 0, tzinfo=<UTC>)
     >>> get_date(datetime(2021, 12, 3, 12, 0, 0).isoformat())
-    datetime.datetime(2021, 12, 3, 12, 0, tzinfo=<StaticTzInfo 'GMT'>)
+    datetime.datetime(2021, 12, 3, 12, 0, tzinfo=<UTC>)
     """
     if value and isinstance(value, str):
         if value == NULL_STRING:
@@ -148,26 +150,26 @@ def get_range(value):
     >>> get_range((None, None))
     (None, None)
     >>> get_range((datetime(2021, 12, 3), None))
-    (datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>), None)
+    (datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>), None)
     >>> get_range('2021-12-03,null')
-    (datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>), None)
+    (datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>), None)
     >>> get_range((None, datetime(2021, 12, 3)))
-    (None, datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>))
+    (None, datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>))
     >>> get_range('null,2021-12-03')
-    (None, datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>))
+    (None, datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>))
     >>> get_range((datetime(2021, 12, 1), datetime(2021, 12, 3)))
-    (datetime.datetime(2021, 12, 1, 0, 0, tzinfo=<StaticTzInfo 'GMT'>),
-     datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>))
+    (datetime.datetime(2021, 12, 1, 0, 0, tzinfo=<UTC>),
+     datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>))
     >>> get_range('2021-12-01,2021-12-03')
-    (datetime.datetime(2021, 12, 1, 0, 0, tzinfo=<StaticTzInfo 'GMT'>),
-     datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<StaticTzInfo 'GMT'>))
+    (datetime.datetime(2021, 12, 1, 0, 0, tzinfo=<UTC>),
+     datetime.datetime(2021, 12, 3, 0, 0, tzinfo=<UTC>))
     """
     if isinstance(value, str):
         value = value.split(LIST_SEPARATOR)
     return tuple(map(get_date, value))
 
 
-class InList:
+class InPropertiesList:
     """Check for list items
 
     Items are provided as a dict of sets, where dict keys are the names of searched properties
@@ -175,12 +177,21 @@ class InList:
     values are combined with an "or"; different properties are combined with an "and".
     """
 
+    def __init__(self):
+        container = get_utility(IDocumentContainer)
+        self.index_names = ICatalogPropertiesIndexesContainer(container).index_names
+        
     def __call__(self, params, catalog, index, value):
         for key, vals in value.items():
             queries = None
             for val in vals:
-                queries = or_(queries,
-                              Eq(catalog[index], f'{key}={val}'))
+                if key in self.index_names:
+                    index = f'zfile_property::{key}'
+                    queries = or_(queries,
+                                  Eq(catalog[index], val))
+                else:
+                    queries = or_(queries,
+                                  Eq(catalog[index], f'{key}={val}'))
             params = and_(params, queries)
         return params
 
@@ -207,7 +218,7 @@ INDEX_ARGS = {
     'title': (str.strip, Eq, 'zfile_title'),
     'application_name': (str.strip, Eq, 'zfile_application'),
     'hash': (str.strip, Eq, 'zfile_hash'),
-    'properties': (get_properties, InList, 'zfile_properties'),
+    'properties': (get_properties, InPropertiesList, 'zfile_properties'),
     'tags': (get_list, All, 'zfile_tags'),
     'status': (get_list, Any, 'workflow_state'),
     'creator': (get_list, Any, 'zfile_creator'),
