@@ -16,7 +16,7 @@ This module provides main documents container utility classes.
 """
 
 import datetime
-from datetime import datetime
+from datetime import datetime, timezone
 from xmlrpc.client import DateTime
 
 from dateutil import parser
@@ -46,18 +46,19 @@ from pyams_workflow.interfaces import IWorkflowInfo, IWorkflowState, IWorkflowVe
 from pyams_workflow.versions import get_last_version
 from pyams_zfiles.document import Document, DocumentVersion, get_hash
 from pyams_zfiles.folder import DocumentFolder
-from pyams_zfiles.interfaces import CREATE_DOCUMENT_WITH_OWNER_PERMISSION, IDocumentContainer, IDocumentContainerRoles, \
-    IDocumentFolder, IDocumentVersion, MANAGE_DOCUMENT_PERMISSION, READ_DOCUMENT_PERMISSION, STATE
+from pyams_zfiles.interfaces import CREATE_DOCUMENT_WITH_OWNER_PERMISSION, ICatalogPropertiesIndexesContainerTarget, \
+    IDocumentContainer, IDocumentContainerRoles, IDocumentFolder, IDocumentPropertyExtractorContainerTarget, \
+    IDocumentVersion, MANAGE_DOCUMENT_PERMISSION, READ_DOCUMENT_PERMISSION, STATE
 from pyams_zfiles.search import make_query
 
-
 __docformat__ = 'restructuredtext'
 
 from pyams_zfiles import _
 
 
 @factory_config(IDocumentContainer)
-@implementer(IDefaultProtectionPolicy)
+@implementer(IDefaultProtectionPolicy, ICatalogPropertiesIndexesContainerTarget,
+             IDocumentPropertyExtractorContainerTarget)
 class DocumentContainer(ProtectedObjectMixin, Folder):
     """Document container utility"""
 
@@ -109,7 +110,13 @@ class DocumentContainer(ProtectedObjectMixin, Folder):
             properties['owner'] = request.principal.id
         properties['creator'] = request.principal.id
         # check storage folders
-        folder = self._get_folder(datetime.utcnow())
+        created_time = properties.pop('created_time', None)
+        if isinstance(created_time, DateTime):
+            folder = self._get_folder(parser.parse(created_time.value))
+        elif isinstance(created_time, str):
+            folder = self._get_folder(parser.parse(created_time))
+        else:
+            folder = self._get_folder(datetime.now(timezone.utc))
         # create document and first version
         document, version = self._create_document(registry, folder)
         # update document data and properties
