@@ -22,28 +22,38 @@ from pyams_form.field import Fields
 from pyams_layer.interfaces import IPyAMSLayer
 from pyams_security.interfaces.base import VIEW_SYSTEM_PERMISSION
 from pyams_site.interfaces import ISiteRoot
+from pyams_skin.interfaces.view import IModalPage
 from pyams_skin.interfaces.viewlet import IBreadcrumbItem
 from pyams_utils.adapter import adapter_config
 from pyams_utils.registry import get_utility, query_utility
 from pyams_utils.url import absolute_url
+from pyams_viewlet.manager import viewletmanager_config
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zfiles.interfaces import IDocumentContainer, MANAGE_APPLICATION_PERMISSION, \
     MANAGE_DOCUMENT_PERMISSION
 from pyams_zmi.form import AdminEditForm
-from pyams_zmi.interfaces import IAdminLayer
+from pyams_zmi.interfaces import IAdminLayer, IObjectLabel, TITLE_SPAN_BREAK
+from pyams_zmi.interfaces.form import IFormTitle
 from pyams_zmi.interfaces.table import ITableElementEditor
 from pyams_zmi.interfaces.viewlet import IControlPanelMenu, IMenuHeader, IPropertiesMenu, \
     ISiteManagementMenu
 from pyams_zmi.table import TableElementEditor
+from pyams_zmi.utils import get_object_label
 from pyams_zmi.zmi.viewlet.breadcrumb import AdminLayerBreadcrumbItem
 from pyams_zmi.zmi.viewlet.menu import NavigationMenuItem
 
-
 __docformat__ = 'restructuredtext'
 
 from pyams_zfiles import _  # pylint: disable=ungrouped-imports
 
 
+@adapter_config(required=IDocumentContainer,
+                provides=IObjectLabel)
+def document_container_label(context):
+    """Document container label getter"""
+    return context.__name__
+
+
 @viewlet_config(name='document-container.menu',
                 context=ISiteRoot, layer=IAdminLayer,
                 manager=IControlPanelMenu, weight=40,
@@ -103,11 +113,11 @@ class DocumentContainerBreadcrumbItem(AdminLayerBreadcrumbItem):
     label = _("Documents container")
 
 
-@viewlet_config(name='configuration.menu',
-                context=IDocumentContainer, layer=IAdminLayer,
-                manager=ISiteManagementMenu, weight=20,
-                permission=MANAGE_APPLICATION_PERMISSION,
-                provides=IPropertiesMenu)
+@viewletmanager_config(name='configuration.menu',
+                       context=IDocumentContainer, layer=IAdminLayer,
+                       manager=ISiteManagementMenu, weight=20,
+                       permission=MANAGE_APPLICATION_PERMISSION,
+                       provides=IPropertiesMenu)
 class DocumentContainerPropertiesMenu(NavigationMenuItem):
     """Document container properties menu"""
 
